# pybicpl

[![PyPI - License](https://img.shields.io/pypi/l/pybicpl)](https://github.com/FNNDSC/pybicpl/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/pybicpl)](https://pypi.org/project/pybicpl/)
[![Build](https://github.com/FNNDSC/pybicpl/actions/workflows/release.yml/badge.svg)](https://github.com/FNNDSC/pybicpl/actions)

Python interface for basic MNI .obj file format.
Supports read, write, and calculations on a vertex neighbor graph.

![slideshow](doc/slide.png)
